@@ -39,7 +39,24 @@ class ApplicationLoadBalancerEndpoint(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-globalaccelerator-endpoints.ApplicationLoadBalancerEndpoint",
 ):
-    '''Use an Application Load Balancer as a Global Accelerator Endpoint.'''
+    '''Use an Application Load Balancer as a Global Accelerator Endpoint.
+
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_elasticloadbalancingv2 as elbv2
+        import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+        
+        # application_load_balancer is of type ApplicationLoadBalancer
+        
+        application_load_balancer_endpoint = globalaccelerator_endpoints.ApplicationLoadBalancerEndpoint(application_load_balancer,
+            preserve_client_ip=False,
+            weight=123
+        )
+    '''
 
     def __init__(
         self,
@@ -90,6 +107,19 @@ class ApplicationLoadBalancerEndpointOptions:
 
         :param preserve_client_ip: Forward the client IP address in an ``X-Forwarded-For`` header. GlobalAccelerator will create Network Interfaces in your VPC in order to preserve the client IP address. Client IP address preservation is supported only in specific AWS Regions. See the GlobalAccelerator Developer Guide for a list. Default: true if available
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+            
+            application_load_balancer_endpoint_options = globalaccelerator_endpoints.ApplicationLoadBalancerEndpointOptions(
+                preserve_client_ip=False,
+                weight=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if preserve_client_ip is not None:
@@ -140,7 +170,23 @@ class CfnEipEndpoint(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-globalaccelerator-endpoints.CfnEipEndpoint",
 ):
-    '''Use an EC2 Instance as a Global Accelerator Endpoint.'''
+    '''Use an EC2 Instance as a Global Accelerator Endpoint.
+
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_ec2 as ec2
+        import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+        
+        # cfn_eIP is of type CfnEIP
+        
+        cfn_eip_endpoint = globalaccelerator_endpoints.CfnEipEndpoint(cfn_eIP,
+            weight=123
+        )
+    '''
 
     def __init__(
         self,
@@ -181,6 +227,18 @@ class CfnEipEndpointProps:
         '''Properties for a NetworkLoadBalancerEndpoint.
 
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+            
+            cfn_eip_endpoint_props = globalaccelerator_endpoints.CfnEipEndpointProps(
+                weight=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if weight is not None:
@@ -214,7 +272,24 @@ class InstanceEndpoint(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-globalaccelerator-endpoints.InstanceEndpoint",
 ):
-    '''Use an EC2 Instance as a Global Accelerator Endpoint.'''
+    '''Use an EC2 Instance as a Global Accelerator Endpoint.
+
+    :exampleMetadata: fixture=_generated
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_ec2 as ec2
+        import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+        
+        # instance is of type Instance
+        
+        instance_endpoint = globalaccelerator_endpoints.InstanceEndpoint(instance,
+            preserve_client_ip=False,
+            weight=123
+        )
+    '''
 
     def __init__(
         self,
@@ -265,6 +340,19 @@ class InstanceEndpointProps:
 
         :param preserve_client_ip: Forward the client IP address. GlobalAccelerator will create Network Interfaces in your VPC in order to preserve the client IP address. Client IP address preservation is supported only in specific AWS Regions. See the GlobalAccelerator Developer Guide for a list. Default: true if available
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+            
+            instance_endpoint_props = globalaccelerator_endpoints.InstanceEndpointProps(
+                preserve_client_ip=False,
+                weight=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if preserve_client_ip is not None:
@@ -315,7 +403,45 @@ class NetworkLoadBalancerEndpoint(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-globalaccelerator-endpoints.NetworkLoadBalancerEndpoint",
 ):
-    '''Use a Network Load Balancer as a Global Accelerator Endpoint.'''
+    '''Use a Network Load Balancer as a Global Accelerator Endpoint.
+
+    :exampleMetadata: infused
+
+    Example::
+
+        # Example automatically generated from non-compiling source. May contain errors.
+        import aws_cdk.aws_globalaccelerator as globalaccelerator
+        import aws_cdk.aws_globalaccelerator_endpoints as ga_endpoints
+        import aws_cdk.aws_elasticloadbalancingv2 as elbv2
+        
+        # Create an Accelerator
+        accelerator = globalaccelerator.Accelerator(stack, "Accelerator")
+        
+        # Create a Listener
+        listener = accelerator.add_listener("Listener",
+            port_ranges=[globalaccelerator.PortRange(from_port=80), globalaccelerator.PortRange(from_port=443)
+            ]
+        )
+        
+        # Import the Load Balancers
+        nlb1 = elbv2.NetworkLoadBalancer.from_network_load_balancer_attributes(stack, "NLB1",
+            load_balancer_arn="arn:aws:elasticloadbalancing:us-west-2:111111111111:loadbalancer/app/my-load-balancer1/e16bef66805b"
+        )
+        nlb2 = elbv2.NetworkLoadBalancer.from_network_load_balancer_attributes(stack, "NLB2",
+            load_balancer_arn="arn:aws:elasticloadbalancing:ap-south-1:111111111111:loadbalancer/app/my-load-balancer2/5513dc2ea8a1"
+        )
+        
+        # Add one EndpointGroup for each Region we are targeting
+        listener.add_endpoint_group("Group1",
+            endpoints=[ga_endpoints.NetworkLoadBalancerEndpoint(nlb1)]
+        )
+        listener.add_endpoint_group("Group2",
+            # Imported load balancers automatically calculate their Region from the ARN.
+            # If you are load balancing to other resources, you must also pass a `region`
+            # parameter here.
+            endpoints=[ga_endpoints.NetworkLoadBalancerEndpoint(nlb2)]
+        )
+    '''
 
     def __init__(
         self,
@@ -356,6 +482,18 @@ class NetworkLoadBalancerEndpointProps:
         '''Properties for a NetworkLoadBalancerEndpoint.
 
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
+
+        :exampleMetadata: fixture=_generated
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_globalaccelerator_endpoints as globalaccelerator_endpoints
+            
+            network_load_balancer_endpoint_props = globalaccelerator_endpoints.NetworkLoadBalancerEndpointProps(
+                weight=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if weight is not None:
